#
# spec file for package gnome-sudoku
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-sudoku
Version:        48.1
Release:        1.1
Summary:        Sudoku Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://wiki.gnome.org/Apps/Sudoku
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  blueprint-compiler >= 0.16
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  meson >= 0.59
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.35.7.24
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gtk4) >= 4.10.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(qqwing) >= 1.3.4

%description
Sudoku is a logic puzzle game, in which one must fill a 9 by 9 square
with the correct digits.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}%{_datadir}

%check
%meson_test

%files
%license COPYING
%doc NEWS
%{_datadir}/help/C/%{name}/
%{_datadir}/applications/org.gnome.Sudoku.desktop
%{_datadir}/dbus-1/services/org.gnome.Sudoku.service
%{_datadir}/glib-2.0/schemas/org.gnome.Sudoku.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/org.gnome.Sudoku.metainfo.xml
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_bindir}/%{name}

%files lang -f %{name}.lang

%changelog
* Fri Apr 11 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.1:
  + Fix broken ctrl shortcuts on some setups.
  + Fix trapped focus during pause.
* Fri Mar 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Let the about dialog track appdata releases.
  + Updated translations.
* Fri Feb 28 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + Update the selection highlighting to more closely follow the
    focus
  + Fix the focus jumping around on window resize
  + Fix custom game's missing icon
  + Fix print multiple puzzles dialog's scaling at lower
    resolutions
  + Fix reset puzzle incorrectly affecting the timer after a reload
  + Fix show possibilities setter not working after a reload
  + Add Accessible label to earmark picker buttons
  + Add custom accent color palette of 18 colors
  + Updated translations.
- Add blueprint-compiler BuildRequires: New dependency.
* Fri Jan 31 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Add custom accent color palette of 16 colors
  + Add support for row/column/block highlighting with accent
    colors
  + Update selection and highlighter colors to use oklab
* Fri Jan 10 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.alpha:
  + Port to blueprints
  + Use GtkStack and its animations for the number_picker,
    play/pause and fullscreen/unfullscreen buttons
  + Fix Warnings shortcut not working
  + Add mouse button binding for Back
  + Stop saving elapsed time on game completion when Timer is
    disabled
  + Includes changes from 47.1
  + Updated translations.
* Sat Oct 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1.1:
  + Fix metainfo screenshots
* Fri Oct 18 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Fix tooltip font color in light mode
  + Fix a case when the highlighter doesn't get cleared with undo
  + Fix view not grabbing the focus on start blocking keyboard
    shortcuts
  + Fix reset zoom shortcut not working
  + Fix pause button having no tooltip
  + Fix meson build requirements
  + Updated translations.
* Fri Sep 13 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Switch back all keyboard input to KeyPress
  + The number picker buttons will no longer grab the focus which
    was blocking movement keys and shortcuts
  + Let mouse shortcuts be used in the number picker
  + Always dismiss the picker on number input from the keyboard
  + Add Enter shortcut interaction with earmark mode
  + A lot of backend changes with the number picker
  + Fix number picker not updating on undo/redo
  + Fix undo and redo being usable in pause
  + Updated translations.
* Fri Aug 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Add mouse wheel zoom
  + Use consistent terminology for Puzzle and Game
  + Increase meson requirement to v1.4
  + Change the selection to be a bit lighter in light mode
  + Update default size to 650x700
  + Use variables for app id
  + Change app_id to org.gnome.Sudoku.Devel for gnome nightly
  + Add feature set to metainfo description
  + Updated translations.
* Mon Aug 26 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Add accent color support
  + Add zoom feature, supported by new buttons and the standard
    bindings
  + Move create custom game to the start menu
  + Add mouse button bindings for undo and redo
  + Allow earmark picker in filled cells
  + Adjust play again to skip the start menu
  + Give play custom game success style to make it more visible and
    move it next to the primary menu
  + Disable "New Puzzle" and "Clear Board" while in start menu
  + Fix cell[0, 0] not being selectable on game start
  + Fix highlighter bugs with undo/redo and clear board
  + Fix fixed cells not being counted in custom games
  + Fix clear button adding individual actions to the undo/redo
    stack
  + Fix disable_all_earmarks not grabbing focus on undo/redo
  + Port Message Dialogs to Alert Dialogs
  + Updated translations
- Changes from version 47.alpha:
  + Add preferences dialog with the previously hidden settings
    aswell as new customizations for warnings and the highlighter
  + Add earmark mode button (shortcut e) to toggle earmark input
  + Change warnings to additionally check against the solution by
    default to prevent getting stuck
  + Add autoclean earmarks feature toggleable in preferences
  + Add number picker on second click feature toggleable in
    preferences
  + Add keyboard shortcuts window
  + Change the headerbar and error color to follow adwaita's theme
  + Port AboutDialog and PrintDialog to Adw.Dialog
  + Restore the difficulty in the headerbar as a subtitle
  + Reduce margin sizes and hide the clock when the window gets too
    small
  + Move the paused button to the left side
  + Disable most Sudoku shortcuts in dialogs
  + Change dark mode's highlighter to be more subtle and its
    earmark highlight easier to read
  + Remove Clear Board confirmation, with the stack rework it can
    now be undone with "undo"
  + Remove showing 'X' as warnings
  + Includes changes from 46.1, 46.2, 46.3
  + Updated translations.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.3:
  + Fix GTK allocation warnings.
  + Remove option show-possible-values from --help.
* Mon Jun 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Fix memory leaks.
  + Fix print button not displaying.
* Mon May  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Hide the board during pause.
  + Add pause accelerator.
  + Add single key accelerator for undo, redo, and fullscreen.
  + Add accelerators for warnings (C-w) and highlighter (C-h).
  + Save fullscreen state on exit and add unfullscreen button.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Fix remove clearing too many warnings.
  + Fix long press misbehaving.
  + Remove dark mode outer grid artifacts.
* Mon Mar 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Fix complete board not finishing.
  + Fix warnings not updating correctly.
  + Show fixed cell selection in light mode.
  + Move show_possibilities to a hidden setting.
  + Fix long press not working.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  - Fix pause overlay flashing when game finished.
  - Save difficulty level.
  - Fix crash when creating custom game.
  - Update appdata.
  - Properly destroy window on shutdown.
  - Refactor highlighter and highlight earmarks.
  - Updated translations.
* Fri Dec  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.3:
  + Adjust red warning color to be brighter, to help colorblind
    users
  + Fix earmarks not being checked for warnings
  + Fix crash when using arrow keys with no cell selected
  + Fix criticals when adding earmarks introduced in 45.2
* Fri Oct 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Fix Ctrl+N not setting earmarks
  + Fix warning about failure to solve puzzle when loading games
    with an incorrect value
* Sat Oct 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Fix right click not opening earmark popover.
  + Updated translations.
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + help: remove references to IRC
  + Updated translations.
* Fri Jul 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Major update: port to GTK 4 and libadwaita.
  + Additional changes:
  - Hide popovers when game is paused.
  - Make it possible to clear earmarks from popover.
  - Add WASD keyboard navigation.
  + Updated translations.
- Drop pkgconfig(gtk+-3.0) BuildRequires, no longer needed.
- Add pkgconfig(gtk4) and pkgconfig(libadwaita-1) BuildRequires:
  New dependencies.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Help: Remove references to mailing lists.
  + Updated translations.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Gate extra warnings behind hidden setting.
  + Undo/redo for earmarks is now less broken.
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 44.alpha:
  + Make earmark popover open on long press.
  + Add "wrap around" keyboard navigation.
  + Updated translations.
* Tue Jan 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Revert "Fix redundant undo stack entries for earmarks".
  + Warnings when solution to puzzle is violated no longer consider
    earmarks.
  + Updated translations.
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated application screenshot.
  + Updated translations.
- Add desktop-file-utils BuildRequires: New dependency.
- Following the above new BuildRequires, add optional
  appstream-glib BuildRequires and a check section and
  verify desktop file and metadata during build.
- Stop packaging help files as documentation.
- Replace gcc-c++ with generic c++_compiler and c_compiler
  BuildRequires.
- Drop gobject-introspection BuildRequires: Package does not do
  introspection any more.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Warnings now flag when solution to puzzle is violated.
  + Updated translations.
* Fri Jul  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Add setting to initialize earmarks.
  + Fix redundant undo stack entries for earmarks.
* Fri Mar 18 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + Support Purism form factor.
  + Updated translations.
- Drop merged upstream patch:
  7c9935a02b48f332f67bad3e4ee020b75591084a.patch.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 7c9935a02b48f332f67bad3e4ee020b75591084a.patch: Fix build
  with meson 0.60.0 and newer.
* Sat Jul 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Fix complex text in printed sudokus.
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Fix issue with appdata.
  + Updated translations.
* Tue Mar 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Vala warning fixes.
  + Updated translations.
* Thu Jan 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Choose how many puzzles to print per page.
  + Move game controls to header bar and window menu and improve
    mobile layout.
  + Make game win message dialog modal.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Display incorrect earmarks as red.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Redesign new game menu using a listbox.
  + Do not draw focused or highlighted cell when board is not in
    focus.
  + Highlight all numbers equal to selected one.
- Changes from version 3.37.3:
  + New app icon.
- Changes from version 3.37.2:
  + Remove limit on earmarks.
  + Earmarks are now displayed in fixed positions.
  + Improve earmark picker.
  + Make D-Bus activatable.
  + Additional preparation for GTK 4.
- Changes from version 3.37.1:
  + Various refactoring and preparation for GTK 4.
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Stop calling -%%fdupes on %%{buildroot}/%%{_libexecdir}: no files
  are being installed to this location.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Update link in user help.
* Mon Oct 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix earmark popover regression.
  + Fix appdata release tags.
  + Updated translations.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Sun Sep  1 2019 mgorse@suse.com
- Update to version 3.33.4:
  + Set an earmark instead of the value if earmark picker is
    active.
  + Handle earmarks properly in undo/redo.
  + Make undo and redo hide the value/earmark popovers.
  + Display numbers at top-left in the earmark picker.
  + Place numbers in number picker as on numpad.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Fix crash on print multiple sudokus dialog.
  + Updates to user help.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Updated app ID to org.gnome.Sudoku.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Removed the app menu.
* Fri Sep  7 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Miscellaneous fixes to meson build system.
  + Miscellaneous fixes to user help.
  + Updated translations.
- Drop sudoku-fix-appdata-location.patch (fixed upstream).
- Remove lang package from recommended packages as it already
  supplements main package.
* Wed May 23 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + No visible changes for the user.
- Add:
  + meson BuildRequires and replace configure/make_build/make_\
    install macros with meson/meson_build/meson_install
    respectively, to follow upstream port to Meson build system.
  + sudoku-fix-appdata-location.patch.
- Drop update-desktop-files BuildRequires and suse_update_desktop_\
  file macro: they are no longer needed.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Dec 22 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Remove the OMF file.
  + Updated user docs.
  + Updated help.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Sudoku: current
  Sudoku's web page.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
- Drop %%glib2_gsettings_schema_requires macro: it's no longer
  required since RPM file triggers.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Sun Jul 16 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Remove unnecessary css.
  + Updated translations.
- Drop obsolete post(un) handling, following macros removed:
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post(un).
- Run spec-cleaner, modernize spec.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add flatpak manifest.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92.1:
  + Revert "minor code update" that broke clearing cells.
- Changes from verison 3.23.92:
  + Bump required Vala version to ensure fix for bgo#779955.
  + Add OARS content rating metadata.
  + Minor code updates.
- Add vala BuildRequires: ensure to build from the vala sources
  instead fo the pre-shipped .c sources.
* Mon Nov  7 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Use AX_REQUIRE_DEFINED in configure.ac.
  + Stop using intltool.
  + Update MSGCTXT and PACKAGE_GNU in Makevars.
  + Keep POTFILES in in alphabetical order.
  + Remove trailing whitespace.
  + Add translator comments to the .desktop file.
  + Updated translations.
- Drop intltool BuildRequires: No longer needed.
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + When pause is clicked, the game field should be hidden.
  + Updated translations.
* Fri Aug 19 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Use namespace instead of class for SudokuGenerator.
  + Update appdata.
  + Simplify style-checker enabling code.
  + Fix style-checker with new libgnome-games-support.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + Drop using declarations.
  + Seed RNG for qqwing.
  + Switch to C++ 11.
  + Fix new warnings about static const variables.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Always set header bar as the title bar.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + Properly hide game field during pause and show after resume.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Avoid accidental use of C++ 11.
* Wed Jul 13 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Seed the RNG so we actually get different puzzles each run.
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix window size growing out of control with GTK+ 3.20.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Update license.
  + Use AM_DISTCHECK_CONFIGURE_FLAGS.
  + Bump up the license version on source files.
  + Update CSS for GTK+ 3.19.
  + Require GTK+ 3.19.
  + Update about dialog.
  + Add a missing tag to the AppData file.
  + Updated translations.
- Change license to GPL-3.0+, following upstreams relicensing.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Update doap.
  + Update appdata.
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Increase line width around 3x3.
* Fri Nov  6 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Reorder the buttons on the well done dialog.
  + Fix dragging the window after clicking the game view.
  + Updated translations.
* Sat Aug 15 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Hide number picker after selecting number with keyboard.
  + Fix build with Automake 1.15.
  + Updated translations.
* Mon May 25 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Replace high contrast icons with symbolic icon.
  + Add ability to enter puzzles manually.
  + Clear earmarks when a cell is filled.
  + Use sans font for all numbers when printing.
  + Allow cancelling print multiple puzzles.
  + Revert window title to say Difficulty rather than Puzzle.
  + Destroy GtkPopovers when not needed.
  + Do not save window size on exit if tiled.
  + Update and modernize user help index page.
  + Fix typos and grammar in user help.
  + Temporarily remove user help from app menu pending update.
  + Code cleanups.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Install symbolic icon.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Clear earmarks when a cell is filled.
  + Use sans for all numbers in printed sudokus.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Temporarily remove user help until it can be updated.
- Changes from version 3.15.90:
  + This release rolls back several changes that were present in
    3.15.2, most notably the addition of the timer, since we have
    not yet added scores and there is no point in having a timer
    without scores. The timer is expected to return in the 3.17
    development cycle. No other major changes.
* Sun Nov 30 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + The highlighter can now be turned off with a preference.
  + XDG_CURRENT_DESKTOP may contain a list of desktops.
  + Updated translations.
- Changes from version 3.15.1:
  + Dependencies: GTK+ 3.15.0.
  + Add a timer counting up in the header bar.
  + When the game has been completed, the player may now choose
    between returning to the new game screen and quitting Sudoku,
    instead of returning to the new game screen or starting a new
    puzzle without changing the difficulty level.
  + Thread-safety fixes when printing multiple puzzles.
  + Fix crash when printing more than 16 puzzles on a computer
    with more than 16 CPUs.
  + Improve window titles.
  + Don't set the header bar as the title bar in Unity.
  + Only use a header bar on the print multiple puzzles dialog if
    the desktop environment requests it.
  + Widen the print multiple sudokus dialog.
  + Code cleanups.
  + Updated translations.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fix detection of Unity when XDG_CURRENT_DESKTOP contains a
    list.
  + Updated translations.
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix 100%% CPU usage after generating a puzzle.
  + Only use a header bar on the 'print multiple sudokus-dialog in
    environments that request it.
  + Don't set the main header bar as the title bar in Unity.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fixed multi-threading issues.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix the game in RTL locales.
  + Various code cleanups and improvements.
  + Various window layout and drawing improvements.
  + Add <ctrl>n and <ctrl>r accelerators.
  + Many miscellaneous bugfixes.
  + A few miscellaneous bugfixes.
  + Fix internationalization of game finished dialog.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Started using QQwing as the puzzle generator.
  + Improved the board aesthetics.
  + Printing multiple puzzles is now multi-threaded.
  + Miscellaneous fixes and improvements.
  + Updated translations.
- Add gcc-c++ and pkgconfig(qqwing) BuildRequires: new dependency.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Simplified the new game screen.
  + Improved the number picker design.
  + Lightly shade the current row, column and block.
  + Miscellaneous fixes and improvements.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Redesigned and rewritten.
- Update BuildRequires and Requires according the full rewrite in
  Vala instead of python.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Miscellaneous fixes.
  + Fix crash that was reported by Ubuntu's crash catcher over 5000
    times.
  + Some more stuff is translated now.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fix some bugs with the user help.
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + The colored grid no longer "dances" at the end of the game to
    reduce risk of epileptic seizures.
  + Fix deprecation warnings.
  + Updated translations.
- Add fdupes BuildRequires and run corresponding macro to remove
  duplicated files.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Fix VERSION and PREFIX.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Port to Python 3.
  + Thicken 3x3 grids.
  + Exit on SIGINT.
  + Updated translations.
- Change python-gobject-cairo Requires to python3-gobject-cairo,
  following upstreams port to Python 3.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Appdata is now translatable.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Quit when SIGINT is received instead of ignoring it.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix everything being initially hidden.
  + Fix a crash when clearing notes.
  + Slightly improve the look of the number pad.
  + Fix the high contrast icon.
  + Add an appdata file for GNOME Software.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix running uninstalled.
  + Fix NumberBox events configuration with latest pygobject.
  + Game no longer disappears when opening "print multiple sudokus"
    in fullscreen.
  + Reduce the width of the About dialog.
  + Don't use deprecated GObject.timeout_add_seconds.
  + Use /usr/bin/python instead of /usr/bin/env/python.
  + Fix some broken links in user help.
  + Updated translations.
- Drop gnome-sudoku-numberbox-events.patch: fixed upstream.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Thu Apr 11 2013 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: add automatic typelib()
  requires to the package.
- Add python-gobject-cairo Requires: needed to start the game.
* Thu Apr 11 2013 dimstar@opensuse.org
- Add gnome-sudoku-numberbox-events.patch: Fix NumberBox envents
  configuration with latest pygobject.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Enable maintainer mode by default.
  + Updated translations.
- Add icon_theme_post/postun calls for the new HighContrast icons.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.4. Split-off from gnome-games.
